#
# spec file for package git-review
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           git-review
Version:        1.25.0
Release:        27.2
Summary:        Tool to submit code to Gerrit
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/git-review
#Source0:        http://pypi.python.org/packages/source/g/git-review/git-review-%{version}.tar.gz
Source:         %{name}-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-pbr
BuildRequires:  python-setuptools
Requires:       python-requests >= 1.1
Requires:       python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       python-git-review = %{version}
Obsoletes:      python-git-review < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
# This package does not install into %%{python_sitelib}, thus we have
# to manually tell the dependency on python(abi):
%py_requires
%else
BuildArch:      noarch
%endif

%description
A git command for submitting branches to Gerrit

git-review is a tool that helps submitting git branches to gerrit for
review.

%prep
%setup -q -n git-review-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -m 0644 -D git-review.1 %{buildroot}/%{_mandir}/man1/git-review.1

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.rst
%{python_sitelib}/*
%{_bindir}/git-review
%{_mandir}/man1/git-review.1.gz

%changelog
* Thu Aug 27 2015 tbechtold@suse.com
- Remove %%{_sysconfdir}/git-review/git-review.conf from package.
  File is deprecated.
* Sat Jun 13 2015 tbechtold@suse.com
- update to 1.25.0:
  * Add “git-review -l” to man page synopsis and usage doc
  * Add reviewers on upload
  * Update project links
  * Override E-mail in Gerrit integration tests
  * Fixed a dead link to the git-review docs
  * Provide an explanation on failed rebase
  * Switch to requests to support proxying of 'https'
  * Use plumbing rev-parse to get the branch name
  * Isolate tests from user/system git configuration
  * Push language override down into the cmd wrapper
  * git review -sv gets more verbose
  * Add utf-8 char support
  * Choose tracked branch for rebase when submitting
  * pbr should install the manpage
  * get_remote_url(): also honor url.*.pushInsteadOf
  * Support authentication in run_http_exc
  * Split README.rst into separate doc files
  * Handle correctly http error raise in run_http_exc
  * Fix encoding header
  * Workflow documentation is now in infra-manual
  * Update tests to use Gerrit 2.9.2
  * Use 'no_proxy' env variable in addition to uppercase
  * Enable color support based on tty and config
  * get_remote_url(): honor any "url.<base>.insteadOf" config setting
  * Convert add_remote to use GitReviewExceptions
  * Prefer git-config over git-review config files
  * Isolate tests from user/system config
  * Switched documentation to point to storyboard
  * Fix ---list and "departement" typos in man page
  * Align git-review and python -m git_review.cmd behaviors
  * Define -T/--no-topic to disable review submit with topic
  * Work toward Python 3.4 support and testing
  * -F/--force-rebase has no effect if rebase is disabled by config
  * Remove useless constants
  * Improve windows support for git-review --setup
  * Fix groff warnings with manpage
  * Enabled hacking checks H305 and H307
  * Prevent long subjects in reviews causing spurious blank lines
  * added link to get-pip to readme
  * Disable ssh/scp password authentication during tests
  * Update tests to use Gerrit 2.8.6.1
  * Build universal wheels
* Mon Sep 22 2014 bwiedemann@suse.com
- Require python-setuptools to fix CLI
* Wed Jul 16 2014 bwiedemann@suse.com
- update to 1.24
  * Require python-requests
  * Update homepage on PyPI
  * Update requirements to OpenStack's recommendations
  * Update the README to mention dependencies
  * Ensure username is set for all tests
  * Provide nicer user message for missing remote ref
  * Fix a typo in HACKING.rst
  * Ignore newline in bp/bug search in commit message
  * Restrict tests SSH auth to only the provided key
  * Disable proxies for tests that clone over http
  * Keep track of gerrit.war and golden_site versions
  * Fix typo in manpage s/gireview/gitreview/
  * Correct git review -l over http(s)
* Fri Jul  4 2014 speilicke@suse.com
- Avoid source Url, we're packaging from git
* Thu May 22 2014 dmueller@suse.com
- update to 1.23.61:
  * Topic: do not use '(detached' when detached
  * Use gerrit 2.8.5 instead of gerrit 2.6.1 in tests
  * Allow to specify default scheme in .gitreview file
  * Correct test_remote to support branchs without upstream
  * Remove parsing of --help and variants from our code
  * Python2: fixed UnicodeEncodeError
  * Skip invalid unicode in commit messages
  * Git review assumes the wrong ssh default port
  * Add http(s) protocol support to fetch_review and list_reviews
  * git-review.1 manpage fix for groff warnings
  * Fix parsing of SCP-style URLs, as these are valid in Git itself
  * "git review --setup" failed in Chinese locale
  * Bump hacking version in requirements
  * Reduce testr concurrnecy to 2
  * Add http(s) protocol support to set_hooks_commit_msg
  * Retrieve remote pushurl independently of user's locale
  * Add http(s) protocol support to test_remote
  * Verify if every attached file exists. Attach gerrig.config
  * Wrap exceptions that occur while running external process
  * Make Gerrit port and dir selection deterministic
  * Don't try to attach known_hosts if it's not there
  * Remove tox locale overrides
  * Fix the regex for setting topic
  * Add 2m timeout to tests
  * Attach Gerrit logs and known_hosts to failed tests
  * Change test gerrit ssh/http ports offset
  * Correct .Fl typo WRT --compare in the manual page
  * Ignore content of merge commits in reporting
  * Remove empty lines from git log output
  * Preserve merges when doing a rebase
  * Split git rev-parse --show-toplevel --git-dir on newline
  * Prefer .gitconfig username
  * Add more deterministic port selection for Gerrit
  * Document source location as git.openstack.org
  * Implement integration tests
  * Migrate to pbr
  * No longer check for new git-review releases
- remove git-review-username.diff: merged upstream
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Sep 11 2013 aj@suse.com
- Add patch git-review-username.diff to prefer .gitconfig username
  (see https://review.openstack.org/46015)
- Update to version 1.23:
    Expand multiple commit submission warning.
* Mon Jun  3 2013 vmiklos@suse.com
- Update to version 1.22
- Changes from version 1.20:
  + Allows easy cherry-picking of a change
  + See https://github.com/openstack-infra/git-review/compare/1.20...1.22
* Wed Feb 27 2013 saschpe@suse.de
- Update to version 1.20:
  + Avoid symlinks in the manpage path
- Changes from version 1.19:
  + Allow download of reviews from deleted accounts
  + See https://github.com/openstack-infra/git-review/compare/1.18...1.19
- Renamed from python-git-review, it's a tool not a library
- Install man-page in correct location
- Explicit %%py_requires, since we don't have files in %%python_sitelib
* Thu Sep 20 2012 rhafer@suse.com
- Update to 1.18:
  * Adds Python3 support and various bugfixes
- Package a default configuration file to disable the automatic check
  for new git-review releasess on PyPI. Otherwise git-review refuses
  to work when a new release is available on PyPI
* Thu May 24 2012 saschpe@suse.de
- Initial version
